/*
 * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
 * Copyright (C) 2003-2006 Match Grun and the Sylpheed-Claws team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

/*
 * Some utility functions to access LDAP servers.
 */

#ifndef __LDAPUTIL_H__
#define __LDAPUTIL_H__

#ifdef USE_LDAP

#include <glib.h>

/* Function Prototypes */
GList *ldaputil_read_basedn	( const gchar *host, const gint port,
				  const gchar *bindDN, const gchar *bindPW,
				  const gint tov, int ssl, int tls );
gboolean ldaputil_test_connect	( const gchar *host, const gint port, int ssl, int tls);
gboolean ldaputil_test_ldap_lib	( void );

#endif	/* USE_LDAP */

#endif /* __LDAPUTIL_H__ */

/*
 * End of Source.
 */
